@@ -8,6 +8,6 @@ test_that("World constructor", {
     expect_that(class(world), matches("World"))
     expect_that(class(world@librdf_world), matches("_p_librdf_world_s"))
     err <- try(freeWorld(world), silent=TRUE)
-    expect_that(class(err), not(matches("try-error")))
+    expect_false(class(err) == "try-error")
     
 })
\ No newline at end of file
